@@ -1,22 +1,10 @@
 /*
-   Copyright (C) 2001 Andreas Schlapbach <schlpbch@iam.unibe.ch>
-   Copyright (C) 2003 Antonio Larrosa <larrosa@kde.org>
-   Copyright (C) 2008 Matthias Grimrath <maps4711@gmx.de>
-   Copyright (C) 2020 Jonathan Marten <jjm@keelhaul.me.uk>
+    SPDX-FileCopyrightText: 2001 Andreas Schlapbach <schlpbch@iam.unibe.ch>
+    SPDX-FileCopyrightText: 2003 Antonio Larrosa <larrosa@kde.org>
+    SPDX-FileCopyrightText: 2008 Matthias Grimrath <maps4711@gmx.de>
+    SPDX-FileCopyrightText: 2020 Jonathan Marten <jjm@keelhaul.me.uk>
 
-   This program is free software; you can redistribute it and/or
-   modify it under the terms of the GNU General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with this program; see the file COPYING.  If not, see
-   <http://www.gnu.org/licenses/>.
+    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "archivedialog.h"
@@ -581,9 +569,9 @@ void ArchiveDialog::slotProcessFinished(int exitCode, QProcess::ExitStatus exitS
     if (!message.isEmpty())
     {
         message += xi18nc("@info", "<para>Retain the partial web archive?</para>");
-        if (KMessageBox::questionYesNo(this, message, i18n("Retain Archive?"),
+        if (KMessageBox::questionTwoActions(this, message, i18n("Retain Archive?"),
                                        KGuiItem(i18n("Retain"), KStandardGuiItem::save().icon()),
-                                       KStandardGuiItem::discard())==KMessageBox::No)
+                                       KStandardGuiItem::discard())==KMessageBox::SecondaryAction)
         {
             showMessageAndCleanup(xi18nc("@info",
                                          "Creating the web archive failed."),
