@@ -10,10 +10,12 @@
 #include "konqsettingsxt.h"
 #include "konqdebug.h"
 #include "konqurl.h"
+#include "konqmisc.h"
 
 #include <KWindowInfo>
 #include <KStartupInfo>
 #include <QTimer>
+#include <QX11Info>
 
 // Terminates fullscreen-mode for any full-screen window on the current desktop
 static void abortFullScreenMode()
@@ -57,7 +59,7 @@ KonqMainWindow *KonqMainWindowFactory::createEmptyWindow()
     KonqMainWindow *win = findPreloadedWindow();
     if (win) {
         qCDebug(KONQUEROR_LOG) << "Reusing preloaded window" << win;
-        KStartupInfo::setWindowStartupId(win->winId(), KStartupInfo::startupId());
+        KStartupInfo::setNewStartupId(win->windowHandle(), QX11Info::nextStartupId());
     } else {
         win = new KonqMainWindow(KonqUrl::url(KonqUrl::Type::Blank));
     }
@@ -79,7 +81,7 @@ KonqMainWindow *KonqMainWindowFactory::createNewWindow(const QUrl &url,
         mainWindow->openUrl(nullptr, url, QString(), req);
         mainWindow->setInitialFrameName(req.browserArgs.frameName);
     } else {
-        mainWindow->openUrl(nullptr, QUrl(KonqSettings::startURL()));
+        mainWindow->openUrl(nullptr, KonqMisc::konqFilteredURL(mainWindow, KonqSettings::startURL()));
         mainWindow->focusLocationBar();
     }
     return mainWindow;
